# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'Points of Order'
copyright = '2021 Lee Yingtong Li'
author = 'Lee Yingtong Li'

# The full version, including alpha/beta/rc tags
release = '0.2.1-dev'
version = release


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
	'extension'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


# -- Docutils, etc. options --------------------------------------------------

smartquotes = False


# -- Options for HTML output -------------------------------------------------

html_title = 'Points of Order'

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
#html_theme = 'alabaster'
html_theme = 'potheme_html'
html_theme_path = ['.']
html_sidebars = {'*': ['about.html', 'navigation.html', 'searchbox.html']}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = ['custom_html.css'] # custom.css automatically included by alabaster

html_extra_path = ['epub-cover.xhtml', 'epub-copyright.xhtml']

html_copy_source = False


# -- Options for LaTeX output ------------------------------------------------

latex_engine = 'lualatex'
latex_elements = {
	'passoptionstopackages': r'\input{pass-options.tex.txt}',
	'preamble': r'\input{preamble.tex.txt}',
	#'geometry': r'\usepackage[paperwidth=6in,paperheight=9in,margin=0.5in,bottom=0.75in,inner=0.75in]{geometry}',
	#'geometry': r'\usepackage[paperwidth=5.5in,paperheight=9in,margin=0.5in,bottom=0.75in,inner=0.5in]{geometry}',
	'sphinxsetup': r'AtStartFootnote={},OuterLinkColor={rgb}{0.208,0.374,0.486}',
	'papersize': 'a4paper',
	'pointsize': '11pt',
	'releasename': 'Edition',
}
latex_additional_files = ['pass-options.tex.txt', 'preamble.tex.txt', 'NLA_PDS.eps']
#latex_show_pagerefs = True

latex_documents = [
	('index', 'PointsOfOrder_Web.tex', 'Points of Order', '', 'manual'),
	('index', 'PointsOfOrder_Print.tex', 'Points of Order', '', 'manual'),
]


# -- Options for EPUB output -------------------------------------------------

epub_cover = ('_static/cover.jpg', '')
epub_pre_files = [('epub-cover.xhtml', ''), ('epub-copyright.xhtml', '')]
epub_css_files = ['custom.css', 'custom_epub.css']
epub_show_urls = 'no'
